@@ -223,3 +223,40 @@ def compare_time(time1, time2, format_time='%Y-%m-%d'):
     s_time = time.mktime(time.strptime(time1, format_time))
     e_time = time.mktime(time.strptime(time2, format_time))
     return int(s_time) - int(e_time)
+
+
+def calpreMinu():
+    """
+    计算距离下一分钟还有多少秒
+    :return:
+    """
+    date_1 = datetime.now()
+    date_2 = date_1 + timedelta(minutes=1)  # 同理，后一秒钟设置：seconds=1
+    print(date_1, date_2)
+    dis = date_2-date_1
+    return dis.seconds
+
+
+def isTradeTime() -> bool:
+    """
+    判断是否股票交易时间
+    :return:
+    """
+    now_time = datetime.strptime(datetime.strftime(datetime.now(), '%H:%M:%S'), '%H:%M:%S')
+    # now_time为记录当前时间，由于从Tushare取回的实时分笔数据只有时间，
+    # 没有日期，所以用上面的操作把现在的时间的日期换成1900:1:1日，方便计算时间差
+    rest_time = now_time - datetime.strptime('11:30:00', '%H:%M:%S')
+    # 用来计算当前时间和中午11:30休市时间的差值
+    if rest_time.days == 0 and rest_time.seconds > 0 and rest_time.seconds < 5400:
+        # 中午11:30~13:00为中午休市时间，时长5400 seconds
+        print(f'中午休市时间 {datetime.now()}')
+        return False
+    if rest_time.days == 0 and rest_time.seconds > 12600:
+        # 下午15:00结束交易，与11:30的时间差为12600 seconds，关闭程序
+        print(f'交易时间已结束!{datetime.now()}')
+        return False
+    return True
+
+
+if __name__ == '__main__':
+    print(calpreMinu())
